==> ugene_33.0+dfsg.orig.tar.xz: ugene-33.0/src/corelibs/U2Gui/src/util/project/filter_tasks/ObjectNameFilterTask.cpp <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#include "../ProjectFilterNames.h"

#include "ObjectNameFilterTask.h"

namespace U2 {

//////////////////////////////////////////////////////////////////////////
/// ObjectNameFilterTask
//////////////////////////////////////////////////////////////////////////

ObjectNameFilterTask::ObjectNameFilterTask(const ProjectTreeControllerModeSettings &settings, const QList<QPointer<Document> > &docs)
    : AbstractProjectFilterTask(settings, ProjectFilterNames::OBJ_NAME_FILTER_NAME, docs)
{
    filteredObjCountPerIteration = 50;
}

bool ObjectNameFilterTask::filterAcceptsObject(GObject *obj) {
    return settings.isObjectShown(obj);
}

//////////////////////////////////////////////////////////////////////////
/// ObjectNameFilterTaskFactory
//////////////////////////////////////////////////////////////////////////

AbstractProjectFilterTask * ObjectNameFilterTaskFactory::createNewTask(const ProjectTreeControllerModeSettings &settings,
    const QList<QPointer<Document> > &docs) const
{
    return new ObjectNameFilterTask(settings, docs);
}

} // namespace U2

==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/corelibs/U2Gui/src/util/project/filter_tasks/ObjectNameFilterTask.cpp <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#include "ObjectNameFilterTask.h"

#include "../ProjectFilterNames.h"

namespace U2 {

//////////////////////////////////////////////////////////////////////////
/// ObjectNameFilterTask
//////////////////////////////////////////////////////////////////////////

ObjectNameFilterTask::ObjectNameFilterTask(const ProjectTreeControllerModeSettings &settings, const QList<QPointer<Document>> &docs)
    : AbstractProjectFilterTask(settings, ProjectFilterNames::OBJ_NAME_FILTER_NAME, docs) {
    filteredObjCountPerIteration = 50;
}

bool ObjectNameFilterTask::filterAcceptsObject(GObject *obj) {
    return settings.isObjectShown(obj);
}

//////////////////////////////////////////////////////////////////////////
/// ObjectNameFilterTaskFactory
//////////////////////////////////////////////////////////////////////////

AbstractProjectFilterTask *ObjectNameFilterTaskFactory::createNewTask(const ProjectTreeControllerModeSettings &settings,
                                                                      const QList<QPointer<Document>> &docs) const {
    return new ObjectNameFilterTask(settings, docs);
}

}  // namespace U2
